Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
*slog.Logger
Sugar *zap.SugaredLogger
// contains filtered or unexported fields
}
Contains data to zapLogger and Sugar in some scenario
func NewConsole ¶
Use this function to print logs more friendly on user terminal while keep file logs readable for maintance
Click to show internal directories.
Click to hide internal directories.